==> flowable-mail-7.0.0-sources.jar: org/flowable/mail/common/impl/BaseMailHostServerConfiguration.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.mail.common.impl;

/**
 * @author Filip Hrisafov
 */
public class BaseMailHostServerConfiguration implements MailHostServerConfiguration {

    protected String host;

    protected int port = 25;
    protected Transport transport = Transport.SMTP;

    protected String user;
    protected String password;

    @Override
    public String host() {
        return host;
    }

    public void setHost(String host) {
        this.host = host;
    }

    @Override
    public int port() {
        return port;
    }

    public void setPort(int port) {
        this.port = port;
    }

    @Override
    public Transport transport() {
        return transport;
    }

    public void setTransport(Transport transport) {
        this.transport = transport;
    }

    @Override
    public String user() {
        return user;
    }

    public void setUser(String user) {
        this.user = user;
    }

    @Override
    public String password() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}

==> flowable-mail-7.0.1-sources.jar: org/flowable/mail/common/impl/BaseMailHostServerConfiguration.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.mail.common.impl;

/**
 * @author Filip Hrisafov
 */
public class BaseMailHostServerConfiguration implements MailHostServerConfiguration {

    protected String host;

    protected int port = 25;
    protected Transport transport = Transport.SMTP;
    protected boolean startTlsEnabled;

    protected String user;
    protected String password;

    @Override
    public String host() {
        return host;
    }

    public void setHost(String host) {
        this.host = host;
    }

    @Override
    public int port() {
        return port;
    }

    public void setPort(int port) {
        this.port = port;
    }

    @Override
    public Transport transport() {
        return transport;
    }

    public void setTransport(Transport transport) {
        this.transport = transport;
    }

    @Override
    public boolean isStartTlsEnabled() {
        return startTlsEnabled;
    }

    public void setStartTlsEnabled(boolean startTlsEnabled) {
        this.startTlsEnabled = startTlsEnabled;
    }

    @Override
    public String user() {
        return user;
    }

    public void setUser(String user) {
        this.user = user;
    }

    @Override
    public String password() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }
}
